{% extends 'blueprints/base.html' %}
{% load i18n %}
{% load humanize %}
{% load static %}
{% block details %}

<div class="panel panel-primary">
  <div class="panel-heading">
    <h3 class="panel-title">Blueprints</h3>
  </div>
  <div class="panel-body" style="min-height: 100px">
    <span class="pull-right">
      {% if perms.blueprints.add_blueprint_owner %}
      <a
        class="btn btn-success btn-tabs"
        href="{% url 'blueprints:add_blueprint_owner' %}"
      >
        {% translate "Add Blueprint Owner" %}
      </a>
      {% endif %}
    </span>
    <div
      id="dataExport"
      data-listDataUrl="{% url 'blueprints:list_data' %}?tags={{ active_tags|join:',' }}"
      data-titleAlliance="{% trans 'Alliance' %}"
      data-titleCorporation="{% trans 'Corporation' %}"
      data-titleRegion="{% trans 'Region' %}"
      data-titleSolarSystem="{% trans 'Solar System' %}"
      data-titleCategory="{% trans 'Category' %}"
      data-titleGroup="{% trans 'Group' %}"
      data-Reinforced="{% trans 'Reinforced?' %}"
      data-State="{% trans 'State' %}"
      data-PowerMode="{% trans 'Power Mode' %}"
      data-dataTablesPageLength="{{ data_tables_page_length }}"
      data-dataTablesPaging="{{ data_tables_paging }}"
    ></div>

    <!-- Main structure table -->
    <table
      id="tab_blueprints"
      style="width: 100%"
      class="table table-striped table-compact"
    >
      <thead>
        <tr>
          <th></th>
          <th>{% trans "Type" %}</th>
          <!-- <th>{% trans "Location" %}</th> -->
          <th>{% trans "Owner" %}</th>
          <th>{% trans "Material Efficiency" %}</th>
          <th>{% trans "Time Efficiency" %}</th>
          <th>{% trans "Original" %}</th>
          <th>{% trans "Runs Remaining" %}</th>
        </tr>
      </thead>
    </table>
  </div>
</div>

{% endblock %}
{% block extra_javascript %}
{% include 'bundles/datatables-js.html' %}
<script
  type="application/javascript"
  src="{% static 'js/filterDropDown/filterDropDown.min.js' %}"
></script>
<script
  type="application/javascript"
  src="{% static 'blueprints/blueprint_list.js' %}"
></script>
{% endblock %}
{% block extra_css %}
{% endblock %}
{% block extra_script %}
{% endblock %}
