{% extends 'allianceauth/base.html' %}
{% load i18n %}
{% block page_title %}
{% trans "Blueprint Library" %}
{% endblock %}
{% block content %}
<div class="col-lg-12">
  <h1 class="page-header text-center">{% trans "Blueprint Library" %}</h1>
  <div class="col-lg-12 container">{% block details %}{% endblock %}</div>
</div>
{% endblock %}
